import Taro, { Component } from '@tarojs/taro';
import './index.scss'
import AchievePhone from '@/components/achievePhone'
import AchieveAvatar from '@/components/achieveAvatar'
import { connect } from '@tarojs/redux'
import ready from '@/utils/ready'

@connect(
  ({ user }) => ({ ...user })
)

export default class Index extends Component {
  config = {
    navigationBarTitleText: '房源详情',
  }

  state = {
    grantPhoneVisible: false, // 授权电话
    grantAvatarVisible: false, // 授权头像
  }



  componentWillMount() {

    ready.queue(() => {
      // 分享场景需要先授权手机, 再授权头像
      if (this.toggleGrantPhone()) {
        this.toggleGrantAvatar()
      }


    })
  }



  // 调起授权电话
  toggleGrantPhone = () => {
    const { userInfo: { person: { phone, tel } } } = this.props
    if (!phone && !tel) {
      this.setState({ grantPhoneVisible: true })
      return false
    }
    console.log('phone:', phone, 'tel:', tel, '!!!!!')
    console.log(this.props, 'this.propsphone!!!!!')

    return true
  }

  // 调起授权头像
  toggleGrantAvatar = () => {
    const { userInfo: { person: { avatarurl } } } = this.props

    if (!avatarurl || avatarurl.indexOf('wx.qlogo.cn') === -1) {
      this.setState({ grantAvatarVisible: true })
      return false
    }

    console.log(avatarurl, "avatarurl")
    console.log(this.props.userInfo, "this.props")
    return true
  }
  chooseBtn() {
    Taro.navigateTo({
      url: '/onlineSelling/pages/detail/resultPage'
    })
  }


  render() {
    const { grantPhoneVisible, grantAvatarVisible } = this.state
    const { userInfo = { person: {} } } = this.props

    return (
      <Block>
        {
          grantPhoneVisible &&
          <AchievePhone user={userInfo.person} onSuccess={this.toggleGrantAvatar}></AchievePhone>
        }
        {
          grantAvatarVisible &&
          <AchieveAvatar user={userInfo.person} onSuccess={() => { this.setState({ grantAvatarVisible: false }) }} ></AchieveAvatar>
        }

        <View className='detail'>
          <View className='detail-top'>
            <Image className="norecord-img" mode="aspectFill" src={require('../../assets/norecord.png')}></Image>
            <View className="norecord-text">暂无户型信息</View>
            {/* <Image className="cover-img" mode="aspectFill" src="https://timgsa.baidu.com/timg?image&quality=80&size=b9999_10000&sec=1581369637322&di=6065c2aee90f790b00d0c815f465ebc5&imgtype=0&src=http%3A%2F%2Fcyzs97.com%2FUploads%2FEditor%2FPicture%2F2018-10-18%2F5bc8330f2d06f.jpg"></Image> */}
          </View>
          <ScrollView
            enableBackToTop
            className="wrap"
            scrollY>
            <View className='detail__main'>
              <View style="padding: 0 30rpx;">

                <View className="title">
                  <View className="name">A户型</View>
                  <View className="btn">询问优惠</View>
                </View>
                <View className="price">
                  现价：234万
              </View>
                <View className="area">
                  <Text> 建面<Text style="color:#FE1C1C">270</Text>m²</Text>
                  <Text style="margin-left:20rpx"> 套内<Text style="color:#FE1C1C">270</Text>m²</Text>
                </View>
                <View className="address">
                  <Image className="location-icon" src={require('../../assets/location.png')}></Image> XX嘉园1号楼2单元3楼303号
              </View>
                <View className="date">
                  预选时间：2/12 12:23:33--2/13 12:23:34
              </View>
                <View className="date">
                  认筹时间：2/12 12:23:33--2/13 12:23:34
              </View>
              </View>
              <View className="num">
                已有12人预选此房源，快快预选认筹~
              </View>
              <View style="padding: 0 30rpx;">
                <View className="choose-btn" onClick={()=>this.chooseBtn()}>
                  预选此房源
              </View>
                <View className="close-btn">
                  认筹功能未开放
              </View>
              </View>


            </View>
          </ScrollView>



        </View>

      </Block>
    );
  }
}
